@@ -1,3 +1,5 @@
+( cd opt/kde/share/doc/HTML/it/ark ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/ark ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kdf ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kig ; rm -rf common )
@@ -14,6 +16,10 @@
 ( cd opt/kde/share/doc/HTML/it/kdvi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kgeo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kgeo ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kget ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kget ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kgpg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kgpg ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmag ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmag ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmid ; rm -rf common )
@@ -26,6 +32,8 @@
 ( cd opt/kde/share/doc/HTML/it/kolf ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kpat ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kpdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kpdf ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/korn ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/krec ; rm -rf common )
@@ -36,6 +44,8 @@
 ( cd opt/kde/share/doc/HTML/it/ksim ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/lisa ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/lisa ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kxkb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kxkb ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kalzium ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kalzium ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/katomic ; rm -rf common )
@@ -56,12 +66,16 @@
 ( cd opt/kde/share/doc/HTML/it/kfloppy ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpercentage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kpercentage ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kandy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kandy ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcalc ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kdesu ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcron ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kedit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kedit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kfind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kfind ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kiten ; rm -rf common )
@@ -96,6 +110,12 @@
 ( cd opt/kde/share/doc/HTML/it/kmousetool ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/klinkstatus ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kompare ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kompare ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konsole ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konsole ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kpackage ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/khelpcenter ; rm -rf common )
@@ -108,12 +128,16 @@
 ( cd opt/kde/share/doc/HTML/it/konquest ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kturtle ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kverbos ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kweather ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kwuftpd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kxsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kbugbuster ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmenuedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kioslave ; rm -rf common )
@@ -234,6 +258,8 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/email ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/fonts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/mouse ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/proxy ; rm -rf common )
@@ -256,18 +282,32 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/crypto ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/energy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/netpref ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmktalkd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmcss ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmnotify ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kwindecoration ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/useragent ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlowbatcrit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/keyboard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmfontinst ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kbabel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kbabel ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kamera ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kamera ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kasteroids ; rm -rf common )
@@ -282,6 +322,8 @@
 ( cd opt/kde/share/doc/HTML/it/kdevelop ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kicker ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/klatin ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/klatin ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/klines ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmines ; rm -rf common )
@@ -292,6 +334,8 @@
 ( cd opt/kde/share/doc/HTML/it/kmplot ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/knotes ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/knotes ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kopete ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kopete ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpoker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kpoker ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kruler ; rm -rf common )
@@ -314,12 +358,22 @@
 ( cd opt/kde/share/doc/HTML/it/kreversi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/noatun ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/noatun ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/ksplashml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/ksplashml ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kdebugdialog ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kblackbox ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kblackbox ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcharselect ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/quanta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/quanta ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kuickshow ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kde_app_devel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kommander ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kommander ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kiconedit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/klettres ; rm -rf common )
@@ -330,6 +384,8 @@
 ( cd opt/kde/share/doc/HTML/it/kghostview ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/klickety ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/klickety ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kleopatra ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kleopatra ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kenolaba ; rm -rf common )
@@ -378,8 +434,14 @@
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/protocols ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kate-plugins ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/umbrello ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/umbrello ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/konqueror ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kwordquiz ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/korganizer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/korganizer ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/atlantik ; rm -rf common )
